@@ -1,15 +1,14 @@
 package config
 
 import (
-	"encoding"
 	"errors"
 	"fmt"
 	"runtime"
-
-	"gopkg.in/yaml.v3"
 )
 
 var defaultLintersSettings = LintersSettings{
+	FormatterSettings: defaultFormatterSettings,
+
 	Asasalint: AsasalintSettings{
 		UseBuiltinExclusions: true,
 	},
@@ -33,7 +32,6 @@ var defaultLintersSettings = LintersSettings{
 	},
 	Exhaustive: ExhaustiveSettings{
 		Check:                      []string{"switch"},
-		CheckGenerated:             false,
 		DefaultSignifiesExhaustive: false,
 		IgnoreEnumMembers:          "",
 		PackageScopeOnly:           false,
@@ -43,9 +41,15 @@ var defaultLintersSettings = LintersSettings{
 	Forbidigo: ForbidigoSettings{
 		ExcludeGodocExamples: true,
 	},
-	Gci: GciSettings{
-		Sections:      []string{"standard", "default"},
-		SkipGenerated: true,
+	FuncOrder: FuncOrderSettings{
+		Constructor:  true,
+		StructMethod: true,
+	},
+	Funlen: FunlenSettings{
+		IgnoreComments: true,
+	},
+	GoChecksumType: GoChecksumTypeSettings{
+		DefaultSignifiesExhaustive: true,
 	},
 	Gocognit: GocognitSettings{
 		MinComplexity: 30,
@@ -71,21 +75,12 @@ var defaultLintersSettings = LintersSettings{
 		Scope:  "declarations",
 		Period: true,
 	},
-	Gofmt: GoFmtSettings{
-		Simplify: true,
-	},
-	Gofumpt: GofumptSettings{
-		LangVersion: "",
-		ModulePath:  "",
-		ExtraRules:  false,
-	},
 	Gosec: GoSecSettings{
 		Concurrency: runtime.NumCPU(),
 	},
 	Gosmopolitan: GosmopolitanSettings{
 		AllowTimeLocal:  false,
 		EscapeHatches:   []string{},
-		IgnoreTests:     true,
 		WatchForScripts: []string{"Han"},
 	},
 	Inamedparam: INamedParamSettings{
@@ -102,6 +97,7 @@ var defaultLintersSettings = LintersSettings{
 		Kitlog:           true,
 		Klog:             true,
 		Logr:             true,
+		Slog:             true,
 		Zap:              true,
 		RequireStringKey: false,
 		NoPrintfLike:     false,
@@ -122,11 +118,16 @@ var defaultLintersSettings = LintersSettings{
 		AllowUnused:        false,
 	},
 	PerfSprint: PerfSprintSettings{
+		IntegerFormat: true,
 		IntConversion: true,
+		ErrorFormat:   true,
 		ErrError:      false,
 		ErrorF:        true,
+		StringFormat:  true,
 		SprintF1:      true,
 		StrConcat:     true,
+		BoolFormat:    true,
+		HexFormat:     true,
 	},
 	Prealloc: PreallocSettings{
 		Simple:     true,
@@ -134,7 +135,6 @@ var defaultLintersSettings = LintersSettings{
 		ForLoops:   false,
 	},
 	Predeclared: PredeclaredSettings{
-		Ignore:    "",
 		Qualified: false,
 	},
 	SlogLint: SlogLintSettings{
@@ -159,13 +159,9 @@ var defaultLintersSettings = LintersSettings{
 		SkipRegexp:    `(export|internal)_test\.go`,
 		AllowPackages: []string{"main"},
 	},
-	Unparam: UnparamSettings{
-		Algo: "cha",
-	},
 	Unused: UnusedSettings{
 		FieldWritesAreUses:     true,
 		PostStatementsAreReads: false,
-		ExportedIsUsed:         true,
 		ExportedFieldsAreUsed:  true,
 		ParametersAreUsed:      true,
 		LocalVariablesAreUsed:  true,
@@ -175,6 +171,15 @@ var defaultLintersSettings = LintersSettings{
 		HTTPMethod:     true,
 		HTTPStatusCode: true,
 	},
+	UseTesting: UseTestingSettings{
+		ContextBackground: true,
+		ContextTodo:       true,
+		OSChdir:           true,
+		OSMkdirTemp:       true,
+		OSSetenv:          true,
+		OSTempDir:         false,
+		OSCreateTemp:      true,
+	},
 	Varnamelen: VarnamelenSettings{
 		MaxDistance:   5,
 		MinNameLength: 3,
@@ -190,6 +195,7 @@ var defaultLintersSettings = LintersSettings{
 		AllowCuddleDeclaration:           false,
 		AllowCuddleWithCalls:             []string{"Lock", "RLock"},
 		AllowCuddleWithRHS:               []string{"Unlock", "RUnlock"},
+		AllowCuddleUsedInBlock:           false,
 		ForceCuddleErrCheckAndAssign:     false,
 		ErrorVariableNames:               []string{"err"},
 		ForceExclusiveShortDeclarations:  false,
@@ -197,88 +203,88 @@ var defaultLintersSettings = LintersSettings{
 }
 
 type LintersSettings struct {
-	Asasalint       AsasalintSettings
-	BiDiChk         BiDiChkSettings
-	CopyLoopVar     CopyLoopVarSettings
-	Cyclop          Cyclop
-	Decorder        DecorderSettings
-	Depguard        DepGuardSettings
-	Dogsled         DogsledSettings
-	Dupl            DuplSettings
-	DupWord         DupWordSettings
-	Errcheck        ErrcheckSettings
-	ErrChkJSON      ErrChkJSONSettings
-	ErrorLint       ErrorLintSettings
-	Exhaustive      ExhaustiveSettings
-	Exhaustruct     ExhaustructSettings
-	Forbidigo       ForbidigoSettings
-	Funlen          FunlenSettings
-	Gci             GciSettings
-	GinkgoLinter    GinkgoLinterSettings
-	Gocognit        GocognitSettings
-	Goconst         GoConstSettings
-	Gocritic        GoCriticSettings
-	Gocyclo         GoCycloSettings
-	Godot           GodotSettings
-	Godox           GodoxSettings
-	Gofmt           GoFmtSettings
-	Gofumpt         GofumptSettings
-	Goheader        GoHeaderSettings
-	Goimports       GoImportsSettings
-	Gomnd           GoMndSettings
-	GoModDirectives GoModDirectivesSettings
-	Gomodguard      GoModGuardSettings
-	Gosec           GoSecSettings
-	Gosimple        StaticCheckSettings
-	Gosmopolitan    GosmopolitanSettings
-	Govet           GovetSettings
-	Grouper         GrouperSettings
-	ImportAs        ImportAsSettings
-	Inamedparam     INamedParamSettings
-	InterfaceBloat  InterfaceBloatSettings
-	Ireturn         IreturnSettings
-	Lll             LllSettings
-	LoggerCheck     LoggerCheckSettings
-	MaintIdx        MaintIdxSettings
-	Makezero        MakezeroSettings
-	Misspell        MisspellSettings
-	Mnd             MndSettings
-	MustTag         MustTagSettings
-	Nakedret        NakedretSettings
-	Nestif          NestifSettings
-	NilNil          NilNilSettings
-	Nlreturn        NlreturnSettings
-	NoLintLint      NoLintLintSettings
-	NoNamedReturns  NoNamedReturnsSettings
-	ParallelTest    ParallelTestSettings
-	PerfSprint      PerfSprintSettings
-	Prealloc        PreallocSettings
-	Predeclared     PredeclaredSettings
-	Promlinter      PromlinterSettings
-	ProtoGetter     ProtoGetterSettings
-	Reassign        ReassignSettings
-	Revive          ReviveSettings
-	RowsErrCheck    RowsErrCheckSettings
-	SlogLint        SlogLintSettings
-	Spancheck       SpancheckSettings
-	Staticcheck     StaticCheckSettings
-	Stylecheck      StaticCheckSettings
-	TagAlign        TagAlignSettings
-	Tagliatelle     TagliatelleSettings
-	Tenv            TenvSettings
-	Testifylint     TestifylintSettings
-	Testpackage     TestpackageSettings
-	Thelper         ThelperSettings
-	Unconvert       UnconvertSettings
-	Unparam         UnparamSettings
-	Unused          UnusedSettings
-	UseStdlibVars   UseStdlibVarsSettings
-	Varnamelen      VarnamelenSettings
-	Whitespace      WhitespaceSettings
-	Wrapcheck       WrapcheckSettings
-	WSL             WSLSettings
+	FormatterSettings `mapstructure:"-"`
 
-	Custom map[string]CustomLinterSettings
+	Asasalint       AsasalintSettings       `mapstructure:"asasalint"`
+	BiDiChk         BiDiChkSettings         `mapstructure:"bidichk"`
+	CopyLoopVar     CopyLoopVarSettings     `mapstructure:"copyloopvar"`
+	Cyclop          CyclopSettings          `mapstructure:"cyclop"`
+	Decorder        DecorderSettings        `mapstructure:"decorder"`
+	Depguard        DepGuardSettings        `mapstructure:"depguard"`
+	Dogsled         DogsledSettings         `mapstructure:"dogsled"`
+	Dupl            DuplSettings            `mapstructure:"dupl"`
+	DupWord         DupWordSettings         `mapstructure:"dupword"`
+	Errcheck        ErrcheckSettings        `mapstructure:"errcheck"`
+	ErrChkJSON      ErrChkJSONSettings      `mapstructure:"errchkjson"`
+	ErrorLint       ErrorLintSettings       `mapstructure:"errorlint"`
+	Exhaustive      ExhaustiveSettings      `mapstructure:"exhaustive"`
+	Exhaustruct     ExhaustructSettings     `mapstructure:"exhaustruct"`
+	Fatcontext      FatcontextSettings      `mapstructure:"fatcontext"`
+	Forbidigo       ForbidigoSettings       `mapstructure:"forbidigo"`
+	FuncOrder       FuncOrderSettings       `mapstructure:"funcorder"`
+	Funlen          FunlenSettings          `mapstructure:"funlen"`
+	GinkgoLinter    GinkgoLinterSettings    `mapstructure:"ginkgolinter"`
+	Gocognit        GocognitSettings        `mapstructure:"gocognit"`
+	GoChecksumType  GoChecksumTypeSettings  `mapstructure:"gochecksumtype"`
+	Goconst         GoConstSettings         `mapstructure:"goconst"`
+	Gocritic        GoCriticSettings        `mapstructure:"gocritic"`
+	Gocyclo         GoCycloSettings         `mapstructure:"gocyclo"`
+	Godot           GodotSettings           `mapstructure:"godot"`
+	Godox           GodoxSettings           `mapstructure:"godox"`
+	Goheader        GoHeaderSettings        `mapstructure:"goheader"`
+	GoModDirectives GoModDirectivesSettings `mapstructure:"gomoddirectives"`
+	Gomodguard      GoModGuardSettings      `mapstructure:"gomodguard"`
+	Gosec           GoSecSettings           `mapstructure:"gosec"`
+	Gosmopolitan    GosmopolitanSettings    `mapstructure:"gosmopolitan"`
+	Govet           GovetSettings           `mapstructure:"govet"`
+	Grouper         GrouperSettings         `mapstructure:"grouper"`
+	Iface           IfaceSettings           `mapstructure:"iface"`
+	ImportAs        ImportAsSettings        `mapstructure:"importas"`
+	Inamedparam     INamedParamSettings     `mapstructure:"inamedparam"`
+	InterfaceBloat  InterfaceBloatSettings  `mapstructure:"interfacebloat"`
+	Ireturn         IreturnSettings         `mapstructure:"ireturn"`
+	Lll             LllSettings             `mapstructure:"lll"`
+	LoggerCheck     LoggerCheckSettings     `mapstructure:"loggercheck"`
+	MaintIdx        MaintIdxSettings        `mapstructure:"maintidx"`
+	Makezero        MakezeroSettings        `mapstructure:"makezero"`
+	Misspell        MisspellSettings        `mapstructure:"misspell"`
+	Mnd             MndSettings             `mapstructure:"mnd"`
+	MustTag         MustTagSettings         `mapstructure:"musttag"`
+	Nakedret        NakedretSettings        `mapstructure:"nakedret"`
+	Nestif          NestifSettings          `mapstructure:"nestif"`
+	NilNil          NilNilSettings          `mapstructure:"nilnil"`
+	Nlreturn        NlreturnSettings        `mapstructure:"nlreturn"`
+	NoLintLint      NoLintLintSettings      `mapstructure:"nolintlint"`
+	NoNamedReturns  NoNamedReturnsSettings  `mapstructure:"nonamedreturns"`
+	ParallelTest    ParallelTestSettings    `mapstructure:"paralleltest"`
+	PerfSprint      PerfSprintSettings      `mapstructure:"perfsprint"`
+	Prealloc        PreallocSettings        `mapstructure:"prealloc"`
+	Predeclared     PredeclaredSettings     `mapstructure:"predeclared"`
+	Promlinter      PromlinterSettings      `mapstructure:"promlinter"`
+	ProtoGetter     ProtoGetterSettings     `mapstructure:"protogetter"`
+	Reassign        ReassignSettings        `mapstructure:"reassign"`
+	Recvcheck       RecvcheckSettings       `mapstructure:"recvcheck"`
+	Revive          ReviveSettings          `mapstructure:"revive"`
+	RowsErrCheck    RowsErrCheckSettings    `mapstructure:"rowserrcheck"`
+	SlogLint        SlogLintSettings        `mapstructure:"sloglint"`
+	Spancheck       SpancheckSettings       `mapstructure:"spancheck"`
+	Staticcheck     StaticCheckSettings     `mapstructure:"staticcheck"`
+	TagAlign        TagAlignSettings        `mapstructure:"tagalign"`
+	Tagliatelle     TagliatelleSettings     `mapstructure:"tagliatelle"`
+	Testifylint     TestifylintSettings     `mapstructure:"testifylint"`
+	Testpackage     TestpackageSettings     `mapstructure:"testpackage"`
+	Thelper         ThelperSettings         `mapstructure:"thelper"`
+	Unconvert       UnconvertSettings       `mapstructure:"unconvert"`
+	Unparam         UnparamSettings         `mapstructure:"unparam"`
+	Unused          UnusedSettings          `mapstructure:"unused"`
+	UseStdlibVars   UseStdlibVarsSettings   `mapstructure:"usestdlibvars"`
+	UseTesting      UseTestingSettings      `mapstructure:"usetesting"`
+	Varnamelen      VarnamelenSettings      `mapstructure:"varnamelen"`
+	Whitespace      WhitespaceSettings      `mapstructure:"whitespace"`
+	Wrapcheck       WrapcheckSettings       `mapstructure:"wrapcheck"`
+	WSL             WSLSettings             `mapstructure:"wsl"`
+
+	Custom map[string]CustomLinterSettings `mapstructure:"custom"`
 }
 
 func (s *LintersSettings) Validate() error {
@@ -298,7 +304,6 @@ func (s *LintersSettings) Validate() error {
 type AsasalintSettings struct {
 	Exclude              []string `mapstructure:"exclude"`
 	UseBuiltinExclusions bool     `mapstructure:"use-builtin-exclusions"`
-	IgnoreTest           bool     `mapstructure:"ignore-test"`
 }
 
 type BiDiChkSettings struct {
@@ -314,14 +319,12 @@ type BiDiChkSettings struct {
 }
 
 type CopyLoopVarSettings struct {
-	IgnoreAlias bool `mapstructure:"ignore-alias"` // Deprecated: use CheckAlias
-	CheckAlias  bool `mapstructure:"check-alias"`
+	CheckAlias bool `mapstructure:"check-alias"`
 }
 
-type Cyclop struct {
+type CyclopSettings struct {
 	MaxComplexity  int     `mapstructure:"max-complexity"`
 	PackageAverage float64 `mapstructure:"package-average"`
-	SkipTests      bool    `mapstructure:"skip-tests"`
 }
 
 type DepGuardSettings struct {
@@ -356,7 +359,7 @@ type DogsledSettings struct {
 }
 
 type DuplSettings struct {
-	Threshold int
+	Threshold int `mapstructure:"threshold"`
 }
 
 type DupWordSettings struct {
@@ -369,12 +372,6 @@ type ErrcheckSettings struct {
 	CheckTypeAssertions      bool     `mapstructure:"check-type-assertions"`
 	CheckAssignToBlank       bool     `mapstructure:"check-blank"`
 	ExcludeFunctions         []string `mapstructure:"exclude-functions"`
-
-	// Deprecated: use ExcludeFunctions instead
-	Exclude string `mapstructure:"exclude"`
-
-	// Deprecated: use ExcludeFunctions instead
-	Ignore string `mapstructure:"ignore"`
 }
 
 type ErrChkJSONSettings struct {
@@ -398,7 +395,6 @@ type ErrorLintAllowPair struct {
 
 type ExhaustiveSettings struct {
 	Check                      []string `mapstructure:"check"`
-	CheckGenerated             bool     `mapstructure:"check-generated"`
 	DefaultSignifiesExhaustive bool     `mapstructure:"default-signifies-exhaustive"`
 	IgnoreEnumMembers          string   `mapstructure:"ignore-enum-members"`
 	IgnoreEnumTypes            string   `mapstructure:"ignore-enum-types"`
@@ -413,64 +409,33 @@ type ExhaustructSettings struct {
 	Exclude []string `mapstructure:"exclude"`
 }
 
+type FatcontextSettings struct {
+	CheckStructPointers bool `mapstructure:"check-struct-pointers"`
+}
+
 type ForbidigoSettings struct {
 	Forbid               []ForbidigoPattern `mapstructure:"forbid"`
 	ExcludeGodocExamples bool               `mapstructure:"exclude-godoc-examples"`
 	AnalyzeTypes         bool               `mapstructure:"analyze-types"`
 }
 
-var _ encoding.TextUnmarshaler = &ForbidigoPattern{}
-
-// ForbidigoPattern corresponds to forbidigo.pattern and adds mapstructure support.
-// The YAML field names must match what forbidigo expects.
 type ForbidigoPattern struct {
-	// patternString gets populated when the config contains a string as entry in ForbidigoSettings.Forbid[]
-	// because ForbidigoPattern implements encoding.TextUnmarshaler
-	// and the reader uses the mapstructure.TextUnmarshallerHookFunc as decoder hook.
-	//
-	// If the entry is a map, then the other fields are set as usual by mapstructure.
-	patternString string
-
-	Pattern string `yaml:"p" mapstructure:"p"`
+	Pattern string `yaml:"p" mapstructure:"pattern"`
 	Package string `yaml:"pkg,omitempty" mapstructure:"pkg,omitempty"`
 	Msg     string `yaml:"msg,omitempty" mapstructure:"msg,omitempty"`
 }
 
-func (p *ForbidigoPattern) UnmarshalText(text []byte) error {
-	// Validation happens when instantiating forbidigo.
-	p.patternString = string(text)
-	return nil
-}
-
-// MarshalString converts the pattern into a string as needed by forbidigo.NewLinter.
-//
-// MarshalString is intentionally not called MarshalText,
-// although it has the same signature
-// because implementing encoding.TextMarshaler led to infinite recursion when yaml.Marshal called MarshalText.
-func (p *ForbidigoPattern) MarshalString() ([]byte, error) {
-	if p.patternString != "" {
-		return []byte(p.patternString), nil
-	}
-
-	return yaml.Marshal(p)
+type FuncOrderSettings struct {
+	Constructor  bool `mapstructure:"constructor,omitempty"`
+	StructMethod bool `mapstructure:"struct-method,omitempty"`
 }
 
 type FunlenSettings struct {
-	Lines          int
-	Statements     int
+	Lines          int  `mapstructure:"lines"`
+	Statements     int  `mapstructure:"statements"`
 	IgnoreComments bool `mapstructure:"ignore-comments"`
 }
 
-type GciSettings struct {
-	Sections      []string `mapstructure:"sections"`
-	SkipGenerated bool     `mapstructure:"skip-generated"`
-	CustomOrder   bool     `mapstructure:"custom-order"`
-	NoLexOrder    bool     `mapstructure:"no-lex-order"`
-
-	// Deprecated: use Sections instead.
-	LocalPrefixes string `mapstructure:"local-prefixes"`
-}
-
 type GinkgoLinterSettings struct {
 	SuppressLenAssertion       bool `mapstructure:"suppress-len-assertion"`
 	SuppressNilAssertion       bool `mapstructure:"suppress-nil-assertion"`
@@ -483,6 +448,12 @@ type GinkgoLinterSettings struct {
 	ForceExpectTo              bool `mapstructure:"force-expect-to"`
 	ValidateAsyncIntervals     bool `mapstructure:"validate-async-intervals"`
 	ForbidSpecPollution        bool `mapstructure:"forbid-spec-pollution"`
+	ForceSucceedForFuncs       bool `mapstructure:"force-succeed"`
+}
+
+type GoChecksumTypeSettings struct {
+	DefaultSignifiesExhaustive bool `mapstructure:"default-signifies-exhaustive"`
+	IncludeSharedInterfaces    bool `mapstructure:"include-shared-interfaces"`
 }
 
 type GocognitSettings struct {
@@ -490,15 +461,19 @@ type GocognitSettings struct {
 }
 
 type GoConstSettings struct {
-	IgnoreStrings       string `mapstructure:"ignore-strings"`
-	IgnoreTests         bool   `mapstructure:"ignore-tests"`
-	MatchWithConstants  bool   `mapstructure:"match-constant"`
-	MinStringLen        int    `mapstructure:"min-len"`
-	MinOccurrencesCount int    `mapstructure:"min-occurrences"`
-	ParseNumbers        bool   `mapstructure:"numbers"`
-	NumberMin           int    `mapstructure:"min"`
-	NumberMax           int    `mapstructure:"max"`
-	IgnoreCalls         bool   `mapstructure:"ignore-calls"`
+	IgnoreStringValues   []string `mapstructure:"ignore-string-values"`
+	MatchWithConstants   bool     `mapstructure:"match-constant"`
+	MinStringLen         int      `mapstructure:"min-len"`
+	MinOccurrencesCount  int      `mapstructure:"min-occurrences"`
+	ParseNumbers         bool     `mapstructure:"numbers"`
+	NumberMin            int      `mapstructure:"min"`
+	NumberMax            int      `mapstructure:"max"`
+	IgnoreCalls          bool     `mapstructure:"ignore-calls"`
+	FindDuplicates       bool     `mapstructure:"find-duplicates"`
+	EvalConstExpressions bool     `mapstructure:"eval-const-expressions"`
+
+	// Deprecated: use IgnoreStringValues instead.
+	IgnoreStrings string `mapstructure:"ignore-strings"`
 }
 
 type GoCriticSettings struct {
@@ -523,31 +498,10 @@ type GodotSettings struct {
 	Exclude []string `mapstructure:"exclude"`
 	Capital bool     `mapstructure:"capital"`
 	Period  bool     `mapstructure:"period"`
-
-	// Deprecated: use Scope instead
-	CheckAll bool `mapstructure:"check-all"`
 }
 
 type GodoxSettings struct {
-	Keywords []string
-}
-
-type GoFmtSettings struct {
-	Simplify     bool
-	RewriteRules []GoFmtRewriteRule `mapstructure:"rewrite-rules"`
-}
-
-type GoFmtRewriteRule struct {
-	Pattern     string
-	Replacement string
-}
-
-type GofumptSettings struct {
-	ModulePath string `mapstructure:"module-path"`
-	ExtraRules bool   `mapstructure:"extra-rules"`
-
-	// Deprecated: use the global `run.go` instead.
-	LangVersion string `mapstructure:"lang-version"`
+	Keywords []string `mapstructure:"keywords"`
 }
 
 type GoHeaderSettings struct {
@@ -556,72 +510,68 @@ type GoHeaderSettings struct {
 	TemplatePath string                       `mapstructure:"template-path"`
 }
 
-type GoImportsSettings struct {
-	LocalPrefixes string `mapstructure:"local-prefixes"`
-}
-
-// Deprecated: use MndSettings.
-type GoMndSettings struct {
-	MndSettings `mapstructure:",squash"`
-
-	// Deprecated: use root level settings instead.
-	Settings map[string]map[string]any
-}
-
 type GoModDirectivesSettings struct {
 	ReplaceAllowList          []string `mapstructure:"replace-allow-list"`
 	ReplaceLocal              bool     `mapstructure:"replace-local"`
 	ExcludeForbidden          bool     `mapstructure:"exclude-forbidden"`
 	RetractAllowNoExplanation bool     `mapstructure:"retract-allow-no-explanation"`
+	ToolchainForbidden        bool     `mapstructure:"toolchain-forbidden"`
+	ToolchainPattern          string   `mapstructure:"toolchain-pattern"`
+	ToolForbidden             bool     `mapstructure:"tool-forbidden"`
+	GoDebugForbidden          bool     `mapstructure:"go-debug-forbidden"`
+	GoVersionPattern          string   `mapstructure:"go-version-pattern"`
 }
 
 type GoModGuardSettings struct {
-	Allowed struct {
-		Modules []string `mapstructure:"modules"`
-		Domains []string `mapstructure:"domains"`
-	} `mapstructure:"allowed"`
-	Blocked struct {
-		Modules []map[string]struct {
-			Recommendations []string `mapstructure:"recommendations"`
-			Reason          string   `mapstructure:"reason"`
-		} `mapstructure:"modules"`
-		Versions []map[string]struct {
-			Version string `mapstructure:"version"`
-			Reason  string `mapstructure:"reason"`
-		} `mapstructure:"versions"`
-		LocalReplaceDirectives bool `mapstructure:"local_replace_directives"`
-	} `mapstructure:"blocked"`
+	Allowed GoModGuardAllowed `mapstructure:"allowed"`
+	Blocked GoModGuardBlocked `mapstructure:"blocked"`
+}
+
+type GoModGuardAllowed struct {
+	Modules []string `mapstructure:"modules"`
+	Domains []string `mapstructure:"domains"`
+}
+
+type GoModGuardBlocked struct {
+	Modules                []map[string]GoModGuardModule  `mapstructure:"modules"`
+	Versions               []map[string]GoModGuardVersion `mapstructure:"versions"`
+	LocalReplaceDirectives bool                           `mapstructure:"local-replace-directives"`
+}
+
+type GoModGuardModule struct {
+	Recommendations []string `mapstructure:"recommendations"`
+	Reason          string   `mapstructure:"reason"`
+}
+
+type GoModGuardVersion struct {
+	Version string `mapstructure:"version"`
+	Reason  string `mapstructure:"reason"`
 }
 
 type GoSecSettings struct {
-	Includes         []string       `mapstructure:"includes"`
-	Excludes         []string       `mapstructure:"excludes"`
-	Severity         string         `mapstructure:"severity"`
-	Confidence       string         `mapstructure:"confidence"`
-	ExcludeGenerated bool           `mapstructure:"exclude-generated"`
-	Config           map[string]any `mapstructure:"config"`
-	Concurrency      int            `mapstructure:"concurrency"`
+	Includes    []string       `mapstructure:"includes"`
+	Excludes    []string       `mapstructure:"excludes"`
+	Severity    string         `mapstructure:"severity"`
+	Confidence  string         `mapstructure:"confidence"`
+	Config      map[string]any `mapstructure:"config"`
+	Concurrency int            `mapstructure:"concurrency"`
 }
 
 type GosmopolitanSettings struct {
 	AllowTimeLocal  bool     `mapstructure:"allow-time-local"`
 	EscapeHatches   []string `mapstructure:"escape-hatches"`
-	IgnoreTests     bool     `mapstructure:"ignore-tests"`
 	WatchForScripts []string `mapstructure:"watch-for-scripts"`
 }
 
 type GovetSettings struct {
 	Go string `mapstructure:"-"`
 
-	Enable     []string
-	Disable    []string
-	EnableAll  bool `mapstructure:"enable-all"`
-	DisableAll bool `mapstructure:"disable-all"`
+	Enable     []string `mapstructure:"enable"`
+	Disable    []string `mapstructure:"disable"`
+	EnableAll  bool     `mapstructure:"enable-all"`
+	DisableAll bool     `mapstructure:"disable-all"`
 
-	Settings map[string]map[string]any
-
-	// Deprecated: the linter should be enabled inside Enable.
-	CheckShadowing bool `mapstructure:"check-shadowing"`
+	Settings map[string]map[string]any `mapstructure:"settings"`
 }
 
 func (cfg *GovetSettings) Validate() error {
@@ -648,15 +598,20 @@ type GrouperSettings struct {
 	VarRequireGrouping        bool `mapstructure:"var-require-grouping"`
 }
 
+type IfaceSettings struct {
+	Enable   []string                  `mapstructure:"enable"`
+	Settings map[string]map[string]any `mapstructure:"settings"`
+}
+
 type ImportAsSettings struct {
-	Alias          []ImportAsAlias
-	NoUnaliased    bool `mapstructure:"no-unaliased"`
-	NoExtraAliases bool `mapstructure:"no-extra-aliases"`
+	Alias          []ImportAsAlias `mapstructure:"alias"`
+	NoUnaliased    bool            `mapstructure:"no-unaliased"`
+	NoExtraAliases bool            `mapstructure:"no-extra-aliases"`
 }
 
 type ImportAsAlias struct {
-	Pkg   string
-	Alias string
+	Pkg   string `mapstructure:"pkg"`
+	Alias string `mapstructure:"alias"`
 }
 
 type INamedParamSettings struct {
@@ -681,6 +636,7 @@ type LoggerCheckSettings struct {
 	Kitlog           bool     `mapstructure:"kitlog"`
 	Klog             bool     `mapstructure:"klog"`
 	Logr             bool     `mapstructure:"logr"`
+	Slog             bool     `mapstructure:"slog"`
 	Zap              bool     `mapstructure:"zap"`
 	RequireStringKey bool     `mapstructure:"require-string-key"`
 	NoPrintfLike     bool     `mapstructure:"no-printf-like"`
@@ -692,15 +648,14 @@ type MaintIdxSettings struct {
 }
 
 type MakezeroSettings struct {
-	Always bool
+	Always bool `mapstructure:"always"`
 }
 
 type MisspellSettings struct {
-	Mode       string               `mapstructure:"mode"`
-	Locale     string               `mapstructure:"locale"`
-	ExtraWords []MisspellExtraWords `mapstructure:"extra-words"`
-	// TODO(ldez): v2 the option must be renamed to `IgnoredRules`.
-	IgnoreWords []string `mapstructure:"ignore-words"`
+	Mode        string               `mapstructure:"mode"`
+	Locale      string               `mapstructure:"locale"`
+	ExtraWords  []MisspellExtraWords `mapstructure:"extra-words"`
+	IgnoreRules []string             `mapstructure:"ignore-rules"`
 }
 
 type MisspellExtraWords struct {
@@ -709,11 +664,13 @@ type MisspellExtraWords struct {
 }
 
 type MustTagSettings struct {
-	Functions []struct {
-		Name   string `mapstructure:"name"`
-		Tag    string `mapstructure:"tag"`
-		ArgPos int    `mapstructure:"arg-pos"`
-	} `mapstructure:"functions"`
+	Functions []MustTagFunction `mapstructure:"functions"`
+}
+
+type MustTagFunction struct {
+	Name   string `mapstructure:"name"`
+	Tag    string `mapstructure:"tag"`
+	ArgPos int    `mapstructure:"arg-pos"`
 }
 
 type NakedretSettings struct {
@@ -725,7 +682,9 @@ type NestifSettings struct {
 }
 
 type NilNilSettings struct {
-	CheckedTypes []string `mapstructure:"checked-types"`
+	OnlyTwo        *bool    `mapstructure:"only-two"`
+	DetectOpposite bool     `mapstructure:"detect-opposite"`
+	CheckedTypes   []string `mapstructure:"checked-types"`
 }
 
 type NlreturnSettings struct {
@@ -757,22 +716,30 @@ type ParallelTestSettings struct {
 }
 
 type PerfSprintSettings struct {
+	IntegerFormat bool `mapstructure:"integer-format"`
 	IntConversion bool `mapstructure:"int-conversion"`
-	ErrError      bool `mapstructure:"err-error"`
-	ErrorF        bool `mapstructure:"errorf"`
-	SprintF1      bool `mapstructure:"sprintf1"`
-	StrConcat     bool `mapstructure:"strconcat"`
+
+	ErrorFormat bool `mapstructure:"error-format"`
+	ErrError    bool `mapstructure:"err-error"`
+	ErrorF      bool `mapstructure:"errorf"`
+
+	StringFormat bool `mapstructure:"string-format"`
+	SprintF1     bool `mapstructure:"sprintf1"`
+	StrConcat    bool `mapstructure:"strconcat"`
+
+	BoolFormat bool `mapstructure:"bool-format"`
+	HexFormat  bool `mapstructure:"hex-format"`
 }
 
 type PreallocSettings struct {
-	Simple     bool
+	Simple     bool `mapstructure:"simple"`
 	RangeLoops bool `mapstructure:"range-loops"`
 	ForLoops   bool `mapstructure:"for-loops"`
 }
 
 type PredeclaredSettings struct {
-	Ignore    string `mapstructure:"ignore"`
-	Qualified bool   `mapstructure:"q"`
+	Ignore    []string `mapstructure:"ignore"`
+	Qualified bool     `mapstructure:"qualified-name"`
 }
 
 type PromlinterSettings struct {
@@ -791,30 +758,38 @@ type ReassignSettings struct {
 	Patterns []string `mapstructure:"patterns"`
 }
 
+type RecvcheckSettings struct {
+	DisableBuiltin bool     `mapstructure:"disable-builtin"`
+	Exclusions     []string `mapstructure:"exclusions"`
+}
+
 type ReviveSettings struct {
-	Go                    string `mapstructure:"-"`
-	MaxOpenFiles          int    `mapstructure:"max-open-files"`
-	IgnoreGeneratedHeader bool   `mapstructure:"ignore-generated-header"`
-	Confidence            float64
-	Severity              string
-	EnableAllRules        bool `mapstructure:"enable-all-rules"`
-	Rules                 []struct {
-		Name      string
-		Arguments []any
-		Severity  string
-		Disabled  bool
-		Exclude   []string
-	}
-	ErrorCode   int `mapstructure:"error-code"`
-	WarningCode int `mapstructure:"warning-code"`
-	Directives  []struct {
-		Name     string
-		Severity string
-	}
+	Go             string            `mapstructure:"-"`
+	MaxOpenFiles   int               `mapstructure:"max-open-files"`
+	Confidence     float64           `mapstructure:"confidence"`
+	Severity       string            `mapstructure:"severity"`
+	EnableAllRules bool              `mapstructure:"enable-all-rules"`
+	Rules          []ReviveRule      `mapstructure:"rules"`
+	ErrorCode      int               `mapstructure:"error-code"`
+	WarningCode    int               `mapstructure:"warning-code"`
+	Directives     []ReviveDirective `mapstructure:"directives"`
+}
+
+type ReviveRule struct {
+	Name      string   `mapstructure:"name"`
+	Arguments []any    `mapstructure:"arguments"`
+	Severity  string   `mapstructure:"severity"`
+	Disabled  bool     `mapstructure:"disabled"`
+	Exclude   []string `mapstructure:"exclude"`
+}
+
+type ReviveDirective struct {
+	Name     string `mapstructure:"name"`
+	Severity string `mapstructure:"severity"`
 }
 
 type RowsErrCheckSettings struct {
-	Packages []string
+	Packages []string `mapstructure:"packages"`
 }
 
 type SlogLintSettings struct {
@@ -824,13 +799,11 @@ type SlogLintSettings struct {
 	NoGlobal       string   `mapstructure:"no-global"`
 	Context        string   `mapstructure:"context"`
 	StaticMsg      bool     `mapstructure:"static-msg"`
+	MsgStyle       string   `mapstructure:"msg-style"`
 	NoRawKeys      bool     `mapstructure:"no-raw-keys"`
 	KeyNamingCase  string   `mapstructure:"key-naming-case"`
 	ForbiddenKeys  []string `mapstructure:"forbidden-keys"`
 	ArgsOnSepLines bool     `mapstructure:"args-on-sep-lines"`
-
-	// Deprecated: use Context instead.
-	ContextOnly bool `mapstructure:"context-only"`
 }
 
 type SpancheckSettings struct {
@@ -844,9 +817,6 @@ type StaticCheckSettings struct {
 	Initialisms             []string `mapstructure:"initialisms"`                // only for stylecheck
 	DotImportWhitelist      []string `mapstructure:"dot-import-whitelist"`       // only for stylecheck
 	HTTPStatusCodeWhitelist []string `mapstructure:"http-status-code-whitelist"` // only for stylecheck
-
-	// Deprecated: use the global `run.go` instead.
-	GoVersion string `mapstructure:"go"`
 }
 
 func (s *StaticCheckSettings) HasConfiguration() bool {
@@ -861,10 +831,31 @@ type TagAlignSettings struct {
 }
 
 type TagliatelleSettings struct {
-	Case struct {
-		Rules        map[string]string
-		UseFieldName bool `mapstructure:"use-field-name"`
-	}
+	Case TagliatelleCase `mapstructure:"case"`
+}
+
+type TagliatelleCase struct {
+	TagliatelleBase `mapstructure:",squash"`
+	Overrides       []TagliatelleOverrides `mapstructure:"overrides"`
+}
+
+type TagliatelleOverrides struct {
+	TagliatelleBase `mapstructure:",squash"`
+	Package         string `mapstructure:"pkg"`
+	Ignore          bool   `mapstructure:"ignore"`
+}
+
+type TagliatelleBase struct {
+	Rules         map[string]string                  `mapstructure:"rules"`
+	ExtendedRules map[string]TagliatelleExtendedRule `mapstructure:"extended-rules"`
+	UseFieldName  bool                               `mapstructure:"use-field-name"`
+	IgnoredFields []string                           `mapstructure:"ignored-fields"`
+}
+
+type TagliatelleExtendedRule struct {
+	Case                string          `mapstructure:"case"`
+	ExtraInitialisms    bool            `mapstructure:"extra-initialisms"`
+	InitialismOverrides map[string]bool `mapstructure:"initialism-overrides"`
 }
 
 type TestifylintSettings struct {
@@ -873,30 +864,38 @@ type TestifylintSettings struct {
 	EnabledCheckers  []string `mapstructure:"enable"`
 	DisabledCheckers []string `mapstructure:"disable"`
 
-	BoolCompare struct {
-		IgnoreCustomTypes bool `mapstructure:"ignore-custom-types"`
-	} `mapstructure:"bool-compare"`
+	BoolCompare          TestifylintBoolCompare          `mapstructure:"bool-compare"`
+	ExpectedActual       TestifylintExpectedActual       `mapstructure:"expected-actual"`
+	Formatter            TestifylintFormatter            `mapstructure:"formatter"`
+	GoRequire            TestifylintGoRequire            `mapstructure:"go-require"`
+	RequireError         TestifylintRequireError         `mapstructure:"require-error"`
+	SuiteExtraAssertCall TestifylintSuiteExtraAssertCall `mapstructure:"suite-extra-assert-call"`
+}
 
-	ExpectedActual struct {
-		ExpVarPattern string `mapstructure:"pattern"`
-	} `mapstructure:"expected-actual"`
+type TestifylintBoolCompare struct {
+	IgnoreCustomTypes bool `mapstructure:"ignore-custom-types"`
+}
 
-	Formatter struct {
-		CheckFormatString *bool `mapstructure:"check-format-string"`
-		RequireFFuncs     bool  `mapstructure:"require-f-funcs"`
-	} `mapstructure:"formatter"`
+type TestifylintExpectedActual struct {
+	ExpVarPattern string `mapstructure:"pattern"`
+}
 
-	GoRequire struct {
-		IgnoreHTTPHandlers bool `mapstructure:"ignore-http-handlers"`
-	} `mapstructure:"go-require"`
+type TestifylintFormatter struct {
+	CheckFormatString *bool `mapstructure:"check-format-string"`
+	RequireFFuncs     bool  `mapstructure:"require-f-funcs"`
+	RequireStringMsg  bool  `mapstructure:"require-string-msg"`
+}
 
-	RequireError struct {
-		FnPattern string `mapstructure:"fn-pattern"`
-	} `mapstructure:"require-error"`
+type TestifylintGoRequire struct {
+	IgnoreHTTPHandlers bool `mapstructure:"ignore-http-handlers"`
+}
 
-	SuiteExtraAssertCall struct {
-		Mode string `mapstructure:"mode"`
-	} `mapstructure:"suite-extra-assert-call"`
+type TestifylintRequireError struct {
+	FnPattern string `mapstructure:"fn-pattern"`
+}
+
+type TestifylintSuiteExtraAssertCall struct {
+	Mode string `mapstructure:"mode"`
 }
 
 type TestpackageSettings struct {
@@ -917,10 +916,6 @@ type ThelperOptions struct {
 	Begin *bool `mapstructure:"begin"`
 }
 
-type TenvSettings struct {
-	All bool `mapstructure:"all"`
-}
-
 type UseStdlibVarsSettings struct {
 	HTTPMethod         bool `mapstructure:"http-method"`
 	HTTPStatusCode     bool `mapstructure:"http-status-code"`
@@ -929,11 +924,19 @@ type UseStdlibVarsSettings struct {
 	TimeLayout         bool `mapstructure:"time-layout"`
 	CryptoHash         bool `mapstructure:"crypto-hash"`
 	DefaultRPCPath     bool `mapstructure:"default-rpc-path"`
-	OSDevNull          bool `mapstructure:"os-dev-null"` // Deprecated
 	SQLIsolationLevel  bool `mapstructure:"sql-isolation-level"`
 	TLSSignatureScheme bool `mapstructure:"tls-signature-scheme"`
 	ConstantKind       bool `mapstructure:"constant-kind"`
-	SyslogPriority     bool `mapstructure:"syslog-priority"` // Deprecated
+}
+
+type UseTestingSettings struct {
+	ContextBackground bool `mapstructure:"context-background"`
+	ContextTodo       bool `mapstructure:"context-todo"`
+	OSChdir           bool `mapstructure:"os-chdir"`
+	OSMkdirTemp       bool `mapstructure:"os-mkdir-temp"`
+	OSSetenv          bool `mapstructure:"os-setenv"`
+	OSTempDir         bool `mapstructure:"os-temp-dir"`
+	OSCreateTemp      bool `mapstructure:"os-create-temp"`
 }
 
 type UnconvertSettings struct {
@@ -943,13 +946,11 @@ type UnconvertSettings struct {
 
 type UnparamSettings struct {
 	CheckExported bool `mapstructure:"check-exported"`
-	Algo          string
 }
 
 type UnusedSettings struct {
 	FieldWritesAreUses     bool `mapstructure:"field-writes-are-uses"`
 	PostStatementsAreReads bool `mapstructure:"post-statements-are-reads"`
-	ExportedIsUsed         bool `mapstructure:"exported-is-used"` // Deprecated
 	ExportedFieldsAreUsed  bool `mapstructure:"exported-fields-are-used"`
 	ParametersAreUsed      bool `mapstructure:"parameters-are-used"`
 	LocalVariablesAreUsed  bool `mapstructure:"local-variables-are-used"`
@@ -975,11 +976,12 @@ type WhitespaceSettings struct {
 }
 
 type WrapcheckSettings struct {
-	// TODO(ldez): v2 the options must be renamed to use hyphen.
-	IgnoreSigs             []string `mapstructure:"ignoreSigs"`
-	IgnoreSigRegexps       []string `mapstructure:"ignoreSigRegexps"`
-	IgnorePackageGlobs     []string `mapstructure:"ignorePackageGlobs"`
-	IgnoreInterfaceRegexps []string `mapstructure:"ignoreInterfaceRegexps"`
+	ExtraIgnoreSigs        []string `mapstructure:"extra-ignore-sigs"`
+	IgnoreSigs             []string `mapstructure:"ignore-sigs"`
+	IgnoreSigRegexps       []string `mapstructure:"ignore-sig-regexps"`
+	IgnorePackageGlobs     []string `mapstructure:"ignore-package-globs"`
+	IgnoreInterfaceRegexps []string `mapstructure:"ignore-interface-regexps"`
+	ReportInternalErrors   bool     `mapstructure:"report-internal-errors"`
 }
 
 type WSLSettings struct {
@@ -993,6 +995,7 @@ type WSLSettings struct {
 	AllowCuddleDeclaration           bool     `mapstructure:"allow-cuddle-declarations"`
 	AllowCuddleWithCalls             []string `mapstructure:"allow-cuddle-with-calls"`
 	AllowCuddleWithRHS               []string `mapstructure:"allow-cuddle-with-rhs"`
+	AllowCuddleUsedInBlock           bool     `mapstructure:"allow-cuddle-used-in-block"`
 	ForceCuddleErrCheckAndAssign     bool     `mapstructure:"force-err-cuddling"`
 	ErrorVariableNames               []string `mapstructure:"error-variable-names"`
 	ForceExclusiveShortDeclarations  bool     `mapstructure:"force-short-decl-cuddling"`
@@ -1006,15 +1009,15 @@ type CustomLinterSettings struct {
 
 	// Path to a plugin *.so file that implements the private linter.
 	// Only for Go plugin system.
-	Path string
+	Path string `mapstructure:"path"`
 
 	// Description describes the purpose of the private linter.
-	Description string
+	Description string `mapstructure:"description"`
 	// OriginalURL The URL containing the source code for the private linter.
 	OriginalURL string `mapstructure:"original-url"`
 
 	// Settings plugin settings only work with linterdb.PluginConstructor symbol.
-	Settings any
+	Settings any `mapstructure:"settings"`
 }
 
 func (s *CustomLinterSettings) Validate() error {
